@@ -2,9 +2,12 @@
 
 import sys
 
+
 sys.path.insert(0,"/usr/lib/dialcentral/")
 
-from gc_dialer import run_dialpad
 
-run_dialpad()
+import gc_dialer
+
+
+gc_dialer.run_dialpad()
 
